/*
 * Copyright 2010-2023 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.rekognition.model.transform;

import com.amazonaws.services.rekognition.model.*;
import com.amazonaws.transform.SimpleTypeJsonUnmarshallers.*;
import com.amazonaws.transform.*;
import com.amazonaws.util.json.AwsJsonReader;

/**
 * JSON unmarshaller for response DescribeCollectionResult
 */
public class DescribeCollectionResultJsonUnmarshaller implements
        Unmarshaller<DescribeCollectionResult, JsonUnmarshallerContext> {

    public DescribeCollectionResult unmarshall(JsonUnmarshallerContext context) throws Exception {
        DescribeCollectionResult describeCollectionResult = new DescribeCollectionResult();

        AwsJsonReader reader = context.getReader();
        reader.beginObject();
        while (reader.hasNext()) {
            String name = reader.nextName();
            if (name.equals("FaceCount")) {
                describeCollectionResult.setFaceCount(LongJsonUnmarshaller.getInstance()
                        .unmarshall(context));
            } else if (name.equals("FaceModelVersion")) {
                describeCollectionResult.setFaceModelVersion(StringJsonUnmarshaller.getInstance()
                        .unmarshall(context));
            } else if (name.equals("CollectionARN")) {
                describeCollectionResult.setCollectionARN(StringJsonUnmarshaller.getInstance()
                        .unmarshall(context));
            } else if (name.equals("CreationTimestamp")) {
                describeCollectionResult.setCreationTimestamp(DateJsonUnmarshaller.getInstance()
                        .unmarshall(context));
            } else if (name.equals("UserCount")) {
                describeCollectionResult.setUserCount(LongJsonUnmarshaller.getInstance()
                        .unmarshall(context));
            } else {
                reader.skipValue();
            }
        }
        reader.endObject();

        return describeCollectionResult;
    }

    private static DescribeCollectionResultJsonUnmarshaller instance;

    public static DescribeCollectionResultJsonUnmarshaller getInstance() {
        if (instance == null)
            instance = new DescribeCollectionResultJsonUnmarshaller();
        return instance;
    }
}
