/*
 * Copyright 2010-2023 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.rekognition.model.transform;

import com.amazonaws.services.rekognition.model.*;
import com.amazonaws.transform.SimpleTypeJsonUnmarshallers.*;
import com.amazonaws.transform.*;
import com.amazonaws.util.json.AwsJsonReader;

/**
 * JSON unmarshaller for response GetContentModerationResult
 */
public class GetContentModerationResultJsonUnmarshaller implements
        Unmarshaller<GetContentModerationResult, JsonUnmarshallerContext> {

    public GetContentModerationResult unmarshall(JsonUnmarshallerContext context) throws Exception {
        GetContentModerationResult getContentModerationResult = new GetContentModerationResult();

        AwsJsonReader reader = context.getReader();
        reader.beginObject();
        while (reader.hasNext()) {
            String name = reader.nextName();
            if (name.equals("JobStatus")) {
                getContentModerationResult.setJobStatus(StringJsonUnmarshaller.getInstance()
                        .unmarshall(context));
            } else if (name.equals("StatusMessage")) {
                getContentModerationResult.setStatusMessage(StringJsonUnmarshaller.getInstance()
                        .unmarshall(context));
            } else if (name.equals("VideoMetadata")) {
                getContentModerationResult.setVideoMetadata(VideoMetadataJsonUnmarshaller
                        .getInstance()
                        .unmarshall(context));
            } else if (name.equals("ModerationLabels")) {
                getContentModerationResult
                        .setModerationLabels(new ListUnmarshaller<ContentModerationDetection>(
                                ContentModerationDetectionJsonUnmarshaller.getInstance()
                        )
                                .unmarshall(context));
            } else if (name.equals("NextToken")) {
                getContentModerationResult.setNextToken(StringJsonUnmarshaller.getInstance()
                        .unmarshall(context));
            } else if (name.equals("ModerationModelVersion")) {
                getContentModerationResult.setModerationModelVersion(StringJsonUnmarshaller
                        .getInstance()
                        .unmarshall(context));
            } else if (name.equals("JobId")) {
                getContentModerationResult.setJobId(StringJsonUnmarshaller.getInstance()
                        .unmarshall(context));
            } else if (name.equals("Video")) {
                getContentModerationResult.setVideo(VideoJsonUnmarshaller.getInstance()
                        .unmarshall(context));
            } else if (name.equals("JobTag")) {
                getContentModerationResult.setJobTag(StringJsonUnmarshaller.getInstance()
                        .unmarshall(context));
            } else if (name.equals("GetRequestMetadata")) {
                getContentModerationResult
                        .setGetRequestMetadata(GetContentModerationRequestMetadataJsonUnmarshaller
                                .getInstance()
                                .unmarshall(context));
            } else {
                reader.skipValue();
            }
        }
        reader.endObject();

        return getContentModerationResult;
    }

    private static GetContentModerationResultJsonUnmarshaller instance;

    public static GetContentModerationResultJsonUnmarshaller getInstance() {
        if (instance == null)
            instance = new GetContentModerationResultJsonUnmarshaller();
        return instance;
    }
}
