/*
 * Copyright 2010-2023 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.rekognition.model.transform;

import com.amazonaws.services.rekognition.model.*;
import com.amazonaws.transform.SimpleTypeJsonUnmarshallers.*;
import com.amazonaws.transform.*;
import com.amazonaws.util.json.AwsJsonReader;

/**
 * JSON unmarshaller for POJO Label
 */
class LabelJsonUnmarshaller implements Unmarshaller<Label, JsonUnmarshallerContext> {

    public Label unmarshall(JsonUnmarshallerContext context) throws Exception {
        AwsJsonReader reader = context.getReader();
        if (!reader.isContainer()) {
            reader.skipValue();
            return null;
        }
        Label label = new Label();
        reader.beginObject();
        while (reader.hasNext()) {
            String name = reader.nextName();
            if (name.equals("Name")) {
                label.setName(StringJsonUnmarshaller.getInstance()
                        .unmarshall(context));
            } else if (name.equals("Confidence")) {
                label.setConfidence(FloatJsonUnmarshaller.getInstance()
                        .unmarshall(context));
            } else if (name.equals("Instances")) {
                label.setInstances(new ListUnmarshaller<Instance>(InstanceJsonUnmarshaller
                        .getInstance()
                        )
                                .unmarshall(context));
            } else if (name.equals("Parents")) {
                label.setParents(new ListUnmarshaller<Parent>(ParentJsonUnmarshaller.getInstance()
                        )
                                .unmarshall(context));
            } else if (name.equals("Aliases")) {
                label.setAliases(new ListUnmarshaller<LabelAlias>(LabelAliasJsonUnmarshaller
                        .getInstance()
                        )
                                .unmarshall(context));
            } else if (name.equals("Categories")) {
                label.setCategories(new ListUnmarshaller<LabelCategory>(
                        LabelCategoryJsonUnmarshaller.getInstance()
                        )
                                .unmarshall(context));
            } else {
                reader.skipValue();
            }
        }
        reader.endObject();
        return label;
    }

    private static LabelJsonUnmarshaller instance;

    public static LabelJsonUnmarshaller getInstance() {
        if (instance == null)
            instance = new LabelJsonUnmarshaller();
        return instance;
    }
}
