/*
 * Copyright 2010-2023 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.textract.model;

import java.util.HashMap;
import java.util.Map;

/**
 * Entity Type
 */
public enum EntityType {

    KEY("KEY"),
    VALUE("VALUE"),
    COLUMN_HEADER("COLUMN_HEADER"),
    TABLE_TITLE("TABLE_TITLE"),
    TABLE_FOOTER("TABLE_FOOTER"),
    TABLE_SECTION_TITLE("TABLE_SECTION_TITLE"),
    TABLE_SUMMARY("TABLE_SUMMARY"),
    STRUCTURED_TABLE("STRUCTURED_TABLE"),
    SEMI_STRUCTURED_TABLE("SEMI_STRUCTURED_TABLE");

    private String value;

    private EntityType(String value) {
        this.value = value;
    }

    @Override
    public String toString() {
        return value;
    }

    private static final Map<String, EntityType> enumMap;
    static {
        enumMap = new HashMap<String, EntityType>();
        enumMap.put("KEY", KEY);
        enumMap.put("VALUE", VALUE);
        enumMap.put("COLUMN_HEADER", COLUMN_HEADER);
        enumMap.put("TABLE_TITLE", TABLE_TITLE);
        enumMap.put("TABLE_FOOTER", TABLE_FOOTER);
        enumMap.put("TABLE_SECTION_TITLE", TABLE_SECTION_TITLE);
        enumMap.put("TABLE_SUMMARY", TABLE_SUMMARY);
        enumMap.put("STRUCTURED_TABLE", STRUCTURED_TABLE);
        enumMap.put("SEMI_STRUCTURED_TABLE", SEMI_STRUCTURED_TABLE);
    }

    /**
     * Use this in place of valueOf.
     *
     * @param value real value
     * @return EntityType corresponding to the value
     */
    public static EntityType fromValue(String value) {
        if (value == null || value.isEmpty()) {
            throw new IllegalArgumentException("Value cannot be null or empty!");
        } else if (enumMap.containsKey(value)) {
            return enumMap.get(value);
        } else {
            throw new IllegalArgumentException("Cannot create enum from " + value + " value!");
        }
    }
}
