/*
 * Copyright 2010-2023 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.textract.model;

import java.util.HashMap;
import java.util.Map;

/**
 * Relationship Type
 */
public enum RelationshipType {

    VALUE("VALUE"),
    CHILD("CHILD"),
    COMPLEX_FEATURES("COMPLEX_FEATURES"),
    MERGED_CELL("MERGED_CELL"),
    TITLE("TITLE"),
    ANSWER("ANSWER"),
    TABLE("TABLE"),
    TABLE_TITLE("TABLE_TITLE"),
    TABLE_FOOTER("TABLE_FOOTER");

    private String value;

    private RelationshipType(String value) {
        this.value = value;
    }

    @Override
    public String toString() {
        return value;
    }

    private static final Map<String, RelationshipType> enumMap;
    static {
        enumMap = new HashMap<String, RelationshipType>();
        enumMap.put("VALUE", VALUE);
        enumMap.put("CHILD", CHILD);
        enumMap.put("COMPLEX_FEATURES", COMPLEX_FEATURES);
        enumMap.put("MERGED_CELL", MERGED_CELL);
        enumMap.put("TITLE", TITLE);
        enumMap.put("ANSWER", ANSWER);
        enumMap.put("TABLE", TABLE);
        enumMap.put("TABLE_TITLE", TABLE_TITLE);
        enumMap.put("TABLE_FOOTER", TABLE_FOOTER);
    }

    /**
     * Use this in place of valueOf.
     *
     * @param value real value
     * @return RelationshipType corresponding to the value
     */
    public static RelationshipType fromValue(String value) {
        if (value == null || value.isEmpty()) {
            throw new IllegalArgumentException("Value cannot be null or empty!");
        } else if (enumMap.containsKey(value)) {
            return enumMap.get(value);
        } else {
            throw new IllegalArgumentException("Cannot create enum from " + value + " value!");
        }
    }
}
